﻿$(document).ready(function () {
    var selectedIds = [];

    var aId = $('#assessmentId').text();
    var sId = $('#scanId').text();

    var hostDatatable = $('#hostDatatable').DataTable({
        "language": {
            "processing": "Loading data...",
        },
        "stateSave": true,
        "pageLength": 25,
        "lengthMenu": [0, 5, 10, 25, 50, 100, 200, 500],
        "select": true,
        "searching": false,
        "scrollX": true,
        "autoWidth": true,
        "processing": true,
        "serverSide": true,
        "filter": true,
        "ajax": {
            "url": "/api/hosts",
            "type": "POST",
            "datatype": "json",
            "data": {
                assessmentId: aId,
                scanId: sId
            }
        },
        "columnDefs": [
            { "targets": [1], "visible": false, "searchable": false, },
            { "targets": [0], "orderable": false, "searchable": false, },
            {
                "targets": ['_all'],
                render: function (data, type, row) {
                    if (data) {
                        return type === 'display' && data.length > 100 ?
                            data.substr(0, 100) + '…' :
                            data;
                    }
                    else {
                        return " ";
                    }
                }
            }
        ],
        "columns": [
            {
                "render": function (data, type, row, meta) {
                    return `<a href="./View?id=` + row.id + `" type="button" class="btn btn-secondary btn-sm" title="View"><span class="far fa-eye"></span></a>
<a href="/vulnerabilities/list?hostId=` + row.id + `" type="button" class="btn btn-secondary btn-sm" title="View Vulnerabilities"><i class="icon_table"></i></a>
`;
                }
            },
            { "data": "id", "name": "Id" },
            { "data": "ip", "name": "IP", },
            { "data": "name", "name": "Name" },
            { "data": "operatingSystem", "name": "Operating System" },
            { "data": "fqdn", "name": "FQDN" },
            { "data": "netbiosName", "name": "Netbios Name" },
            { "data": "description", "name": "Description" },
            { "data": "numberOfVulnerabilities", "name": "# Vulnerabilities", "orderSequence": [ "desc", "asc" ] },
            { "data": "numberOfCriticalVulnerabilities", "name": "# Critical", "orderSequence": ["desc", "asc"] },
            { "data": "numberOfHighVulnerabilities", "name": "# High", "orderSequence": ["desc", "asc"] },
            { "data": "numberOfMediumVulnerabilities", "name": "# Medium", "orderSequence": ["desc", "asc"] },
            { "data": "numberOfLowVulnerabilities", "name": "# Low", "orderSequence": ["desc", "asc"] },
            { "data": "numberOfInformationalVulnerabilities", "name": "# Informational", "orderSequence": ["desc", "asc"] },
        ],
    });

    /*
     * Handle table select
     * */
    hostDatatable.on('select.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            selectedIds.length = 0; //Clear the array first
            var data = hostDatatable.rows({ selected: true }).data().pluck('id'); //Go through ALL rows to see which are selected

            for (let i = 0; i < data.length; i++) {
                if (!selectedIds.includes(data[i])) { //Only add if not already added
                    selectedIds.push(data[i]);
                }
            }

            if (selectedIds.length > 1) {
                $('#btnEditMultipleHosts').removeClass('disabled');
                $('#btnEditMultipleHosts').attr("href", "./EditMultiple?hostsIds=" + selectedIds.toString());
            }

            console.log("Selected IDs " + selectedIds.toString());
        }
    });

    /*
     * Handle table deselect
     * */
    hostDatatable.on('deselect.dt', function (e, dt, type, indexes) {
        if (type === 'row') {
            var data = hostDatatable.rows(indexes).data().pluck('id');

            for (let i = 0; i < data.length; i++) {
                var index = selectedIds.indexOf(data[i]);
                if (index > -1) {
                    selectedIds.splice(index, 1);
                }
            }

            if (selectedIds.length < 2) {
                $('#btnEditMultipleHosts').addClass('disabled', 'disabled');
                $('#btnEditMultipleHosts').attr("href", "broken" + selectedIds.toString());
            }
            else {
                $('#btnEditMultipleHosts').attr("href", "./EditMultiple?hostsIds=" + selectedIds.toString());
            }

            console.log("Selected IDs " + selectedIds.toString());
        }
    });


    /*
     * Show/hide columns
     * */
    $('button.toggle-vis').on('click', function (e) {
        e.preventDefault();

        // Get the column API object
        var column = hostDatatable.column($(this).attr('data-column'));

        // Toggle the visibility
        column.visible(!column.visible());
    });

    $('input.toogle-column-visibility').on('click', function (e) {
        // Get the column API object
        var column = hostDatatable.column($(this).attr('data-column'));

        // Toggle the visibility
        column.visible(!column.visible());
    });

    $('button.toogle-column-visibility-select-special').on('click', function (e) {
        if (this.id === "customSwitchShowAll") {
            showAllColumns();
        }
        else if (this.id === "customSwitchHideAll") {
            hideAllColumns();
        }
    });

    /*
     * Set correct state on visibility switches when modul loads
     * */
    $('a.show-hide-columns').on('click', function (e) {
        setCorrectSwitchStates();
    });

    function setCorrectSwitchStates() {
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");

        for (let i = 0; i < allCheckboxes.length; i++) {
            var column = hostDatatable.column($(allCheckboxes[i]).attr('data-column'));
            var isVisible = column.visible();
            if (isVisible == true) {
                allCheckboxes[i].checked = true;
            }
            else {
                allCheckboxes[i].checked = false;
            }
        }
    }

    function showAllColumns() {
        hostDatatable.columns().visible(true);
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");
        hostDatatable.columns([1]).visible(false); //Exceptions, always hide this column
        for (let i = 0; i < allCheckboxes.length; i++) {
            allCheckboxes[i].checked = true;
        }
    }

    function hideAllColumns() {
        hostDatatable.columns().visible(false);
        hostDatatable.columns([0]).visible(true); //Exceptions, never hide this column
        var allCheckboxes = document.getElementsByClassName("toogle-column-visibility");

        for (let i = 0; i < allCheckboxes.length; i++) {
            allCheckboxes[i].checked = false;
        }
    }
});